@@ -17,7 +17,7 @@
 #
 import json
 
-from PyQt5.QtWidgets import QWidget, QVBoxLayout, QAction, QFileDialog
+from qtpy.QtWidgets import QAction, QWidget, QVBoxLayout, QFileDialog
 
 from dpp.core import Context
 from dpp.core.plugin import PluginType
